@@ -15,7 +15,7 @@
 # along with this program.  If not, see <https://www.gnu.org/licenses/>.
 
 __license__ = 'GPLv3'
-__version__ = '1.0.0'
+__version__ = '1.1.0'
 
 run_help = '''TBlock - An anticapitalist ad-blocker that uses the hosts file
 Copyright (c) 2021 Twann <twann@ctemplar.com>
@@ -38,6 +38,7 @@ usage: tblock <operation> <options>
   -C  --add-custom   [id]     [file/url]  Subscribe to a custom filter
   -R  --remove       [filter]             Remove a filter (unsubscribe)
   -U  --update       [filter]             Update a filter
+  -Q  --search       [query]  [options]   Search a query in the filter lists
   -M  --mod          [a|b|r]  [filter]    Change permissions of a filter
   -X  --change-id    [filter] [new-id]    Change the ID of a custom filter
   -I  --info         [filter]             Show information about a filter
@@ -48,17 +49,17 @@ usage: tblock <operation> <options>
   -D  --restore                           Restore default hosts file
 
 <options>
-* General
+* General options
   -f  --force                             Do not prompt user for anything
-* Rules
+* Filters options
+  -y  --sync                              Update remote filters repository
+* List options
   -t  --standard                          Only show standard rules
   -u  --user                              Only show user rules
-* Filters
-  -y  --sync                              Update remote filters repository
-  -c  --custom                            List only custom filters
-  -k  --subscribed                        List only subscribed filters
-  -n  --unsubscribed                      List only unsubscribed filters
-  -w  --on-remote-repo                    List only filters available on remote repository
+  -c  --custom                            Only show custom filters
+  -k  --subscribing                       Only show subscribed filters
+  -n  --unsubscribing                     Only show unsubscribed filters
+  -w  --on-remote-repo                    Only show filters available on remote repository
 
 For more information, see tblock(1)'''
 
