@@ -16,6 +16,7 @@
 # along with this program.  If not, see <https://www.gnu.org/licenses/>.
 
 # Standard libraries
+import os.path
 import sys
 import re
 import sqlite3
@@ -31,7 +32,7 @@ from .rules import add_rules, list_rules, delete_rules
 from .converter import convert_filter, get_syntax
 from .utils import check_root, unlock_database
 from .filters import subscribe_to_filters, show_filters, update_filters, update_all_filters, unsubscribe_from_filters, \
-    list_filters, change_filters_permissions, change_filter_id
+    list_filters, change_filters_permissions, change_filter_id, search_filters
 from .exceptions import FilterNotExists, MissingArgumentError, FilterSourceExistsError, NotSubscribingError, \
     RuleNotExistsError, InvalidBindAddress, SIGTERM, InvalidFilterSyntax, NetworkError, FilterNotCustomError, \
     FilterExistsError
@@ -50,6 +51,7 @@ tblock_args = [
     '-C', '--add-custom',
     '-R', '--remove',
     '-U', '--update',
+    '-Q', '--search',
     '-M', '--mod',
     '-X', '--change-id',
     '-I', '--info',
@@ -312,7 +314,7 @@ def parse_args_tblock() -> None:
     elif parser.action == 'add-custom':
         data = []
         for filter_id in parser.values:
-            data.append([filter_id, 'b', parser.values[parser.values.index(filter_id) + 1]])
+            data.append([filter_id, 'b', os.path.realpath(parser.values[parser.values.index(filter_id) + 1])])
             parser.values.pop(parser.values.index(filter_id) + 1)
         subscribe_to_filters(data, parser.options['force'])
         if parser.options['sync']:
@@ -334,6 +336,11 @@ def parse_args_tblock() -> None:
             print()
             sync_remote_repo(parser.options['force'])
 
+    elif parser.action == 'search':
+        for query in parser.values:
+            search_filters(query, parser.options['on-remote-repo'], parser.options['custom'],
+                           parser.options['subscribing'], parser.options['unsubscribing'])
+
     elif parser.action == 'mod':
         data = []
         try:
@@ -441,13 +448,15 @@ def run() -> None:
     except (PermissionError, FilterSourceExistsError, MissingArgumentError, FilterNotExists, NotSubscribingError,
             RuleNotExistsError, InvalidBindAddress, InvalidFilterSyntax, FileNotFoundError, NetworkError,
             FilterExistsError, FilterNotCustomError) as err:
-        print(err)
+        print(str(err).replace('[Errno 2] N', 'n'))
         unlock_database()
         sys.exit(1)
     except sqlite3.OperationalError:
-        print(f'{Fore.RED}ERROR: database error: please run "tblock -Y" as superuser '
+        print(f'{Fore.RED}ERROR: database error: please run "tblock -Yf" as superuser '
               f'to resolve this problem{Style.RESET_ALL}')
         sys.exit(1)
+    except sqlite3.DatabaseError:
+        print(f'{Fore.RED}ERROR: database may be locked or corrupted: please run "tblock -Yf" as superuser')
     except (SIGTERM, KeyboardInterrupt):
         unlock_database()
         sys.exit(1)
@@ -460,7 +469,7 @@ def run_converter() -> None:
         parse_args_tblockc()
     except (PermissionError, FilterSourceExistsError, MissingArgumentError, FilterNotExists, NotSubscribingError,
             RuleNotExistsError, InvalidBindAddress, InvalidFilterSyntax, FileNotFoundError) as err:
-        print(err)
+        print(str(err).replace('[Errno 2] N', 'n'))
         sys.exit(1)
     except (SIGTERM, KeyboardInterrupt):
         exit(1)
