@@ -600,6 +600,10 @@ def unsubscribe_from_filters(filters: list, force: bool = False) -> None:
         unlock_database()
     except PermissionError:
         raise PermissionError(f'{Fore.RED}ERROR: permission error{Style.RESET_ALL}')
+    try:
+        open(Path.NEEDS_UPDATE, 'wt').close()
+    except PermissionError:
+        pass
 
 
 def update_filters(filters: list, force: bool = False) -> None:
@@ -675,6 +679,10 @@ def update_all_filters(force: bool = False) -> None:
         force (bool, optional): Do not prompt user (False by default)
     """
     update_filters(get_all_id(subscribing=True, not_subscribing=False), force)
+    try:
+        os.remove(Path.NEEDS_UPDATE)
+    except (FileNotFoundError, PermissionError):
+        pass
 
 
 def show_filters(filters: list) -> None:
@@ -690,7 +698,9 @@ def show_filters(filters: list) -> None:
             raise FilterNotExists(f'{Fore.RED}ERROR: filter does not exist: {filter_id}{Style.RESET_ALL}')
     for filter_id in filters:
         filter_obj = Filter(filter_id)
+        print('----------------------------------------------')
         filter_obj.show()
+    print('----------------------------------------------')
 
 
 def list_filters(online_only: bool = False, custom_only: bool = False,
@@ -728,3 +738,48 @@ def list_filters(online_only: bool = False, custom_only: bool = False,
     else:
         for filter_id in get_all_id(subscribing, not_subscribing):
             print(filter_id)
+
+
+def search_filters(query: str, online_only: bool = False, custom_only: bool = False,
+                   subscribing_only: bool = False, not_subscribing_only: bool = False) -> None:
+    """Search a query in the filters list and their metadata
+
+    Args:
+        query (str): The query to search
+        online_only (bool, optional): Show only results from filters that are available on the remote repository
+        custom_only (bool, optional): Show only results from custom filters
+        subscribing_only (bool, optional): Show only results from filters that the user is subscribing to
+        not_subscribing_only (bool, optional): Show only results from filters that the user is not subscribing to
+    """
+    regex_query = re.compile(query, re.IGNORECASE)
+    if subscribing_only and not_subscribing_only:
+        subscribing = False
+        not_subscribing = False
+    elif subscribing_only and not not_subscribing_only:
+        subscribing = True
+        not_subscribing = False
+    elif not_subscribing_only and not subscribing_only:
+        subscribing = False
+        not_subscribing = True
+    else:
+        subscribing = True
+        not_subscribing = True
+
+    if online_only and custom_only:
+        filters_list = []
+    elif online_only and not custom_only:
+        filters_list = get_all_from_rfr(subscribing, not_subscribing)
+    elif custom_only and not online_only:
+        filters_list = get_all_custom()
+    else:
+        filters_list = get_all_id(subscribing, not_subscribing)
+
+    for filter_id in filters_list:
+        if re.findall(regex_query, Filter(filter_id).id):
+            print(filter_id)
+        elif re.findall(regex_query, Filter(filter_id).metadata['title']):
+            print(filter_id)
+        elif re.findall(regex_query, Filter(filter_id).metadata['description']):
+            print(filter_id)
+        else:
+            pass
