@@ -9,6 +9,7 @@ import unittest
 
 tblock.config.Path.HOSTS = os.path.join(os.path.abspath(os.path.dirname(__file__)), 'root', 'hosts')
 tblock.config.Path.DATABASE = os.path.join(os.path.abspath(os.path.dirname(__file__)), 'root', 'storage.sqlite')
+tblock.config.Path.DB_LOCK = os.path.join(os.path.abspath(os.path.dirname(__file__)), 'root', '.db-lock')
 tblock.config.Path.TMP_DIR = os.path.join(os.path.abspath(os.path.dirname(__file__)), 'root')
 tblock.config.Path.HOSTS_VERIFICATION = os.path.join(os.path.abspath(os.path.dirname(__file__)), 'root', 'verification')
 tblock.config.setup_database(tblock.config.Path.DATABASE)
@@ -38,6 +39,10 @@ class TestSubscribeFilters(unittest.TestCase):
         )
 
     def test_subscribe_to_unsupported_filetype_remove(self):
+        try:
+            os.remove(tblock.config.Path.DB_LOCK)
+        except FileNotFoundError:
+            pass
         self.assertEquals(
             filters.unsubscribe_from_filters(['test-filter-error'], force=True),
             None
